""" Interfaces
"""
from zope.interface import Interface, Attribute
from zope.schema import List, Choice
try:
    from Products.EEAContentTypes import interfaces as eeafaces
    IFeedPortletInfo = eeafaces.IFeedPortletInfo
except ImportError:
    class IFeedPortletInfo(Interface):
        """ Fallback if EEAContentTypes not present
        """

class IRDFRepository(Interface):
    """ A utility that uses a plugin system to allow finding and dealing
        with RDF pluggable.
    """

    def getFeeds(self, types, searchfor):
        """ Returns a list of the feeds that are available, where each
            feed has a list of rss/rdf entries/items.

            types --list (default: [])
            searchfor --list (default: {})
        """

    def getPluginNames(self):
        """ Returns the names of all RDF Repository plugins.
        """

class IRDFRepositoryPlugin(Interface):
    """ All rdf repository plugins must implement this interface.
    """

    def getFeeds(self, types, searchfor):
        """ Returns all feeds that matches the search criteria.

            types --list (default: [])
            searchfor --list (default: {})
        """

    def name(self):
        """ Return the name of the plugin.
        """

class IFeedDiscover(Interface):
    """ A feed that can be discovered can tell the RDF Repository what
        attributes of the items that should be searched. title, subject
        and description are typical item attributes to be searched on.
    """

    search_attrs = List(
        title = u"Attributes to search",
        description = u"List of attributes that discover should consider "
                     "when doing its search",
        required = False,
        value_type = Choice(
            title = u"Attribute",
            vocabulary = """Discover Attributes""",
            )
        )

class IFeed(Interface):
    """ A generic interface for all feeds (rss and rdf). All feeds have
        id, title, url and items.
    """
    id = Attribute("feed id")
    title = Attribute("feed title")
    items = Attribute("feed items")
    home_url = Attribute("feed home url")
    feed_url = Attribute("actual feed url")
    items = Attribute("feed items")

    def get(self, attr):
        """ Tries to fetch an arbitrary attribute from the feed.
        """

class IFeedInfo(IFeed):
    """ A data-only (no logic) feed object. IFeed adapter can be asked what
        items what items are in the feed. IFeedInfo doesn't have this logic,
        but it someone else can set the items attribute so it's available
        to others.
    """

class IFeedItem(Interface):
    """ All feed items have title and url. It's possible to get other
        attributes by using the get method. When IFeed is asked about
        the feed items it respondes with a list of objects providing
        this interface.
    """

    title = Attribute("feed item title")
    url = Attribute("feed item url")

    def get(self, attr):
        """ Tries to get attr from the feed item. If it doesn't exist None is
            returned.
        """

class IFeedContent(Interface):
    """ Marker interface for all feed objects.
    """

#class IRDFRepository(Interface):
#    """ Marker interface for RDF repositories. """

class IRDFPortletDataCollector(Interface):
    """ An object that provides this interface promises that it knows how
        to get rdf/rss feeds considering the context.
    """
    feeds = Attribute("feeds with items that the adapter decides to return")

class IRDFPortletInfo(IFeedPortletInfo):
    """ Provides the data for showing a feed in a template.
    """
